@@ -55,6 +55,9 @@ struct lldpctl_conn_t {
 #define CONN_STATE_GET_DEFAULT_PORT_SEND 15
 #define CONN_STATE_GET_DEFAULT_PORT_RECV 16
 #define CONN_STATE_WATCHING		17
+#define CONN_STATE_SET_CHASSIS_SEND	18
+#define CONN_STATE_SET_CHASSIS_RECV	19
+
 	int state;		/* Current state */
 	/* Data attached to the state. It is used to check that we are using the
 	 * same data as a previous call until the state machine goes to
